@@ -2,4 +2,5 @@ from .command import run
 import sys
 
 if __name__ == '__main__':
-    run(sys.argv[1], sys.argv[2])
+    args =sys.argv[1:]
+    run(*args)
